# pytool-telegram

This is a package for Kasheesh python tools


## Environment Variables

This library requires the following environment variables to be set:

- `AWS_ACCESS_KEY_ID`: The API for accessing AWS.
- `AWS_SECRET_ACCESS_KEY`: The API key for accessing AWS.

Example:
```bash
export DB_PORT='your_db_port'

